#!/usr/bin/perl

  require '../../apache-lib.pl';
  require '../../../guardiandigital-lib.pl';
  &ReadParse();


  ### ##########################################################################
  ### Setup all of our variables and complain if we don't have any #############
  ### ##########################################################################
  ### Variables for httpd.conf
  $HTTPD_CONF      = "/etc/httpd/conf/httpd.conf";
  $FQDN            = $in{'FQDN'};
  $STORENAME       = $in{'STORENAME'};
  $ADMIN_EMAIL     = $in{'ADMIN_EMAIL'};
  $BASEDIR         = $in{'BASEDIR'};
  $STORE_USERNAME  = $in{'STORE_USERNAME'};
  $STORE_GROUPNAME = $in{'STORE_GROUPNAME'};


  ### Null input checks.
  if (!$FQDN) { &PrintError("Please enter a valid domain name."); exit; }
  if (!$STORENAME) { &PrintError("Please enter a store name."); exit; }
  if (!$ADMIN_EMAIL) { 
    &PrintError("Please enter the administrative e-mail address."); exit;
  }
  if ($STORE_USERNAME eq "Please Select") { 
    &PrintError("Please select a user name"); exit;
  }
  if ($STORE_GROUPNAME eq "Please Select") { 
    &PrintError("Please select a group name"); exit;
  }

  ### Data formatting checks.
  if ($FQDN !~ m/^[A-Za-z0-9\-\.]+\.[A-Za-z]+$/) {
    &PrintError("'$FQDN' is not a valid fully-qualified domain name.");
  }
  if ($STORENAME !~ m/.{1,16}/) {
    &PrintError("The Store Name cannot be longer then 16 characters."); exit;
  }
  if ($STORENAME !~ m/^[A-Za-z0-9\_]+$/) {
    &PrintError("The Store Name can only be alphanumeric."); exit;
  }
  if ($ADMIN_EMAIL !~ m/^.*@.*$/) {
    &PrintError("'$ADMIN_EMAIL' is an invalid e-mail address.'");
  }

  ##############################################################################
  ### Make sure database does not exist.
  ##############################################################################
    ### Get the root password.
    open FILE, "/etc/webtool/SystemManager/config";
      while (<FILE>) { if ($_ =~ m/^pass\=(.*)$/) { $dbi_pass = $1; } }
    close FILE;

    ### Make the connection to the DBMS on localhost.
    use DBI;
    $dbh = DBI->connect("DBI:mysql:host=localhost:database=$STORENAME",                                 "root", "$dbi_pass");

    if ($dbh) {
      &PrintError("The store '$STORENAME' already exists.");
      $dbh->disconnect();
    }

  ##############################################################################
  ### Make sure database does not exist.
  ##############################################################################


  ### Good ol' header.
  &header("Steup a Store:  Step 2 of 3", "");

  ### Build help link strings.
  $sitename_help      = hlink("Site Name", "SiteName");
  $zipcode_help       = hlink("Store Zip Code", "StoreZipCode");
  $adminpass_help     = hlink("Administrator Password", "AdminPass");
  $adminpass2_help    = hlink("Administrator Password Verification", "AdminPass2");
  $csmail_help        = hlink("Customer Service E-Mail", "CSEmail");
  $ordermail_help     = hlink("Order E-Mail", "OEmail");
  $webmastermail_help = hlink("Webmaster E-Mail", "WEmail");
  $payproc_help       = hlink("Pay Process", "PayProcess");
  $storestate_help    = hlink("Store State", "StoreState");
  $taxrate_help       = hlink("Tax Rate", "TaxRate");
  $dbuser_help        = hlink("Database Username", "DbUser");
  $dbpass_help        = hlink("Database Password", "DbPass");
  $dbpass2_help       = hlink("Database Password Verification", "DbPass2");
  $replymail_help     = hlink("Reply To E-Mail", "REmail");

print <<EOF;
  <FORM ACTION="setup_ssl.cgi" METHOD="POST">
  <INPUT TYPE="HIDDEN" NAME="FQDN" VALUE="$FQDN">
  <INPUT TYPE="HIDDEN" NAME="STORENAME" VALUE="$STORENAME">
  <INPUT TYPE="HIDDEN" NAME="ADMIN_EMAIL" VALUE="$ADMIN_EMAIL">
  <INPUT TYPE="HIDDEN" NAME="BASEDIR" VALUE="$BASEDIR">
  <INPUT TYPE="HIDDEN" NAME="STORE_USERNAME" VALUE="$STORE_USERNAME">
  <INPUT TYPE="HIDDEN" NAME="STORE_GROUPNAME" VALUE="$STORE_GROUPNAME">

  <INPUT TYPE="HIDDEN" NAME="site_dbiuser" VALUE="$STORENAME">

  <CENTER><TABLE BORDER="0" WIDTH="620" CELLPADDING="0" CELLSPACING=0>
  <TR $tb><TD COLSPAN=2><DIV CLASS=ttitle><B>Setup a Store</B></DIV></TD></TR>
  <TR $cb><TD COLSPAN=2>&nbsp;</TD></TR>
  <TR $cb><TD COLSPAN=2><DIV CLASS=nbody>
    Below is the AllCommerce configuration portion of setting up a new store.

    <UL>
      <LI><B>Site Name</B> is a name which will be used on all of the adminstrations screens.
      <LI><B>Store Zip Code</B> is the zip code of where the warehouse resides.
      <LI><B>Administrator Password</B> is the password that is used to access the administrative screens.
      <LI><B>Administrator Password Verification</B> is the password again, to verify that it is entered correctly.
      <LI><B>Customer Service E-Mail</B> is the email address of the customer service department.
      <LI><B>Order E-Mail</B> is the email address of the department that handles orders.
      <LI><B>Webmaster E-Mail</B> is the email address of the site webmaster.
      <LI><B>Pay Process</B> is the method that you plan to use to accept payments on your virtual store.
      <LI><B>Store State</B> is the US state that the store is located in. This will be used for tax and shipping purposes.
      <LI><B>Tax Rate</B> is the tax rate for the given state.
      <LI><B>Database Username</B> is the username that will be used internally for all of the stores databases.
      <LI><B>Database Password</B> is the password that will be used, with the given username, for internal databases accesses.
      <LI><B>Database Password Verification</B> is the password again, to verify that it is entered correctly.
      <LI><B>Reply To E-Mail</B> is the default email address for the customer to reply to should they have an inquiry.
    </UL>

    <P><B>The next part of the configuration is setting up mail and SSL.</B>
  </TD></TR>

  <TR $cb><TD COLSPAN=2>&nbsp;</TD></TR>
  <TR $cb>
    <TD WIDTH=20>&nbsp;</TD>
    <TD>
      <TABLE BORDER=0 WIDTH=100% CELLSPACING=0 CELLPADDING=0>

      <TR $tb>
        <TD COLSPAN="2"><DIV CLASS="thead"><B>AllCommerce Configuration</B></TD>
      </TR>


      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$sitename_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="sitename" SIZE="30"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$zipcode_help</B></DIV></TD>
        <TD>

          <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="100%">
          <TR>
            <TD>
              <INPUT TYPE="TEXT" NAME="zipcode" SIZE="5" MAXLENGTH="5">
            </TD>
            <TD>
              <B CLASS="toolfont">WARNING:  Be sure this value is correct or the
              <BR>shipping methods may not work properly.</B>
            </TD>
          </TR>
          </TABLE>

        </TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$adminpass_help</B></DIV></TD>
        <TD><INPUT TYPE="PASSWORD" NAME="admin_pass" SIZE="16" MAXLENGTH="16"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$adminpass2_help</B></DIV></TD>
        <TD><INPUT TYPE="PASSWORD" NAME="admin_pass2" SIZE="16" MAXLENGTH="16"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$csmail_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="customer_service_email_address" SIZE="30"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$ordermail_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="order_email_address" SIZE="30"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$webmastermail_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="webmaster_email_address" SIZE="30"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$payproc_help</B></DIV></TD>
        <TD><DIV CLASS="nbody">
          <SELECT NAME="payprocess">
            <OPTION VALUE="none">none</OPTION>
            <OPTION VALUE="cybercash">CyberCash</OPTION>
          </SELECT>
        </TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$storestate_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="storestate" SIZE="2" MAXLENGTH="2"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$taxrate_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="taxrate" SIZE="5" MAXLENGTH="5">%</TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$dbpass_help</B></DIV></TD>
        <TD><INPUT TYPE="PASSWORD" NAME="site_dbipwd" SIZE="16" MAXLENGTH="16"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$dbpass2_help</B></DIV></TD>
        <TD><INPUT TYPE="PASSWORD" NAME="site_dbipwd2" SIZE="16" MAXLENGTH="16"></TD>
      </TR>

      <TR $cb>
        <TD><DIV CLASS="nbody"><B>$replymail_help</B></DIV></TD>
        <TD><INPUT TYPE="TEXT" NAME="replyto" SIZE="30"></TD>
      </TR>

      <TR $cb>
        <TD COLSPAN="2" ALIGN="RIGHT"><DIV CLASS=nbody>
          <INPUT TYPE="SUBMIT" VALUE="Next Step">
        </TD>
      </TR>
      </TABLE>
    </TD>
  </TR>
  </TABLE></CENTER></FORM><P>
EOF

  ### Good ol' footer.
  &ryanFooter("/VHost/opensales/");
