#!/usr/bin/perl

  require '../../apache-lib.pl';
  require '../../../guardiandigital-lib.pl';
  &ReadParseMime();

  if ($in{'newpair'}) {
    &redirect("generate_certificate.cgi?store=$in{'store'}&SSLStatus=$in{'SSLStatus'}");
    exit;
  }

  ### ############################ #############################################
  ### We want to update the store. #############################################
  ### ############################ #############################################

  $store                 = $in{'store'};
  $ssl_certificate       = $in{'certfile'};
  $ssl_key               = $in{'keyfile'};

  $SERVERINDEX_443       = $in{'SERVERINDEX_443'};
  $SSLCertificateFile    = "/home/httpd/$store/ssl/certificate.pem";
  $SSLCertificateKeyFile = "/home/httpd/$store/ssl/key.pem";



  ### ##########################################################################
  ### Case 1:  We want to upload both a new certficate AND key.
  ### NOTE:  This is the only case in which the httpd.conf needs updating.
  ### ##########################################################################
  if ($ssl_certificate && $ssl_key) {

    ### Get temp files for md5 comparison.
    $cert_tmp = &tempname(); $key_tmp = &tempname();

    ### Write the certificate to a temp file.
    open CERT_TMP, ">$cert_tmp";
      print CERT_TMP $in{'certfile'};
    close CERT_TMP;

    ### Write the key to a temp file.
    open KEY_TMP, ">$key_tmp";
      print KEY_TMP $in{'keyfile'};
    close KEY_TMP;


    ### Check the validity of the certificate.
    if (`openssl x509 -noout -modulus -in $cert_tmp 2>&1` =~ m/unable/) {
      &PrintError("You have entered an invalid certificate."); exit;
    }

    ### Check the validity of the key.
    if (`openssl rsa -noout -modulus -in $key_tmp 2>&1` =~ m/unable/) {
      &PrintError("You have entered an invalid key."); exit;
    }


    ### Get the md5 sum of the of the modulus of both the certificate and key.
    $cert_out = `openssl x509 -noout -modulus -in $cert_tmp | openssl md5`;
    $key_out = `openssl rsa -noout -modulus -in $key_tmp | openssl md5`;

    ### If the modulus (moduli?) do not match then the pair is not valid.
    if ($cert_out ne $key_out) {
      &PrintError("The certificate and key do not match each other."); exit;
    }

    ### Remove the temp file.
    unlink $cert_tmp;

    ### Okay, we've now got a valid certificate and a valid key that match.
    ###   - Move the new certificate and key into place.
    ###   - Make both files 0400, owned by www.

    open CERTIFICATE, ">$SSLCertificateFile";
      print CERTIFICATE $ssl_certificate;
    close CERTIFICATE;

    open KEY, ">$SSLCertificateKeyFile";
      print KEY $ssl_key;
    close KEY;

    chmod 0400, $SSLCertificateFile, $SSLCertificateKeyFile;
    system "/bin/chown www.www $SSLCertificateFile, $SSLCertificateKeyFile";

    ### ############################################## ###
    ### Save the directives with our new certificates. ###
    ### ############################################## ###
    if (!$in{'SSLStatus'}) {
      ### #####################################################################
      ### Find the proper virtual server index. ###############################
      ### #####################################################################
      $apache_conf = &get_config();
      @virt = &find_directive_struct("VirtualHost", $apache_conf);

      foreach $v (@virt) {
        $INDEX = &indexof($v, @$apache_conf);
        $vconf = &get_config()->[$INDEX];
        ($nvh, $Port) = ($v->{'value'} =~ /^(\S+):(\S+)$/);
        if (!$Port) { $Port = "80"; }

        $docroot = &find_directive_struct("DocumentRoot", $vconf->{'members'});
        $admin   = &find_directive_struct("ServerAdmin", $vconf->{'members'});
        $name    = &find_directive_struct("ServerName", $vconf->{'members'});

        if ($Port == 443) {
          if ($docroot->{'words'}[0] eq "/home/httpd/$store") {
            $SERVERINDEX_443 = $INDEX;
          }
        }
      }

      ### ######################################################################
      ### Get our virtual config, and update the proper directives. ############
      ### ######################################################################

      ### Get our config.
      $conf = &get_config();
      $vconf = $conf->[$SERVERINDEX_443];

      ### Read our file lines in.
      $lref = &read_file_lines($vconf->{'file'});

      ### Turn on SSL.
      &save_directive("SSLEngine", [ "on" ], $vconf->{'members'}, $conf);

      ### Update the SSLCertificateFile directive.
      &save_directive("SSLCertificateFile", [ $SSLCertificateFile ],
                    $vconf->{'members'}, $conf);

      ### Update the SSLCertificateKeyFile directive.
      &save_directive("SSLCertificateKeyFile", [ $SSLCertificateKeyFile ],
                      $vconf->{'members'}, $conf);

      ### Write the file back to disk.
      &flush_file_lines();
    }




    ### We're all done.  The NEW certificate is in place with the NEW key.
    ### Let's go back two levels.
    system "/etc/init.d/httpd restart"; sleep 1;
    &PrintError("The new certificate and key have been uploaded successfully", "-2");
  }



  ### ##########################################################################
  ### Case 2:  We want to upload a certificate and use the existing key. #######
  ### ##########################################################################
  elsif ($ssl_certificate && ($ssl_key eq "")) {

    ### We dont have an existing key, so die.
    if (!-e "$SSLCertificateKeyFile") {
      &PrintError("You do not have an exsting key so you must upload one.");
      exit;
    }

    ### Get temp file for uploaded cert, and put it in.
    $cert_tmp = &tempname();
    open CERT_TMP, ">$cert_tmp";
      print CERT_TMP $ssl_certificate;
    close CERT_TMP;


    ### Check the validity of the newly-uploaded certificiate.
    if (`openssl x509 -noout -modulus -in $cert_tmp 2>&1` =~ m/unable/) {
       &PrintError("You have entered an invalid certificate.");
       exit;
     }

    ### Take md5sum of new certificate and existing key.
    $cert_out = `openssl x509 -noout -modulus -in $cert_tmp | openssl md5`;
    $key_out = `openssl rsa -noout -modulus -in $SSLCertificateKeyFile | openssl md5`;

    ### If the modulus (moduli?) do not match then the pair is not valid.
    if ($cert_out ne $key_out) {
      &PrintError("The new certificate does not match the existing key.");
       exit;
    }

    ### Okay, we've now got a valid certificate and a valid key that match.
    ###   - Move the new certificate into place.
    ###   - Make both files 0400, owned by www.

    open CERTIFICATE, ">$SSLCertificateFile";
      print CERTIFICATE $ssl_certificate;
    close CERTIFICATE;

    chmod 0400, $SSLCertificateFile, $SSLCertificateKeyFile;
    system "/bin/chown www.www $SSLCertificateFile, $SSLCertificateKeyFile";


    ### Remove the temp file.
    unlink $cert_tmp;


    ### We're all done.  The new certificate is in place with the old key.
    ### Let's go back two levels.
    system "/etc/init.d/httpd restart"; sleep 1;
    &PrintError("The new certificate has been uploaded successfully", "-2");
  }



  ### ##########################################################################
  ### Case 3:  We want to upload a key and use the existing certificate. #######
  ### ##########################################################################
  elsif (($ssl_certificate eq "") && $ssl_key) {
    &PrintError("You can not upload a key without a new certificate.");
    exit;
  }



  ### ##########################################################################
  ### Case 4: Neither a certificate nor key were entered, so don't do anything.
  ### ##########################################################################

  &redirect("/VHost/opensales/edit");


